<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="zh_HK" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation type="vanished">關於</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>分類：</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>開始Torrent</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>略過驗證碼檢查</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>建立子資料夾</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Torrent管理模式：</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>全部</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>未分類</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>加入分類…</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>清除分類</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>清除未使用分類</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>回復Torrent</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>暫停Torrent</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>刪除Torrent</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>新分類</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>編輯分類…</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>關閉qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>一行一連結</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>整體上載速度限制：請停用或設定大於零。</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>整體下載速度限制：請停用或設定大於零。</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>特別上載速度限制：請停用或設定大於零。</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>特別下載速度限制：請停用或設定大於零。</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>最大活躍下載數量須大於-1。</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>最大活躍上載數量須大於-1。</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>最大活躍Torrent數量須大於-1。</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>整體最大連接數量限制：請停用或設定大於零。</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>每個Torrent最大連接數量限制：請停用或設定大於零。</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>每個Torrent最大上載通道數量限制：請停用或設定大於零。</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>無法儲存喜好設定：可能連接不到qBittorrent。</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC：#qbittorrent於Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>分享率限制須介乎0至9998。</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>做種時限須介乎0至525600分鐘。</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>連入埠數值須介乎1至65535。</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>Web UI遠端控制埠數值須介乎1至65535。</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>無法登入：可能連接不到qBittorrent。</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>無效用戶名稱或密碼。</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用戶名</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>登入</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>原作者</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>套用</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>加入</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>上載Torrent</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>儲存檔案到：</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Cookie：</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>在此輸入資料夾</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>更多資訊</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>關於憑證的資訊</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>設定存放位置</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>限制上載速度</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>限制下載速度</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>重新命名Torrent</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>其他…</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>星期一</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>星期二</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>星期三</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>星期四</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>星期五</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>星期六</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>星期日</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>登出</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>從網址或磁性連結下載Torrent</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>上載本機Torrent</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>從傳輸清單清除所選Torrent，確定？</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>連接不到qBittorrent用戶端</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>整體上載通道數量限制：請停用或設定大於零。</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>無效分類名稱：\n分類名稱不准使用特殊字元。</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>無法建立分類</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>上載速度下限須大於零。</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>編輯</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>可用空間：%1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>Torrent不活躍時間須大於零。</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>存檔管理</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>下載速度下限須大於零。</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qBittorrent已關閉</translation>
    </message>
    <message>
        <source>Open documentation</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Register to handle magnet links...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Unable to add peers. Please ensure you are adhering to the IP:port format.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name cannot be empty</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name is unchanged</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Failed to update name</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>項目</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>工具</translation>
    </message>
    <message>
        <source>File</source>
        <translation>檔案</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>程式</translation>
    </message>
    <message>
        <source>View</source>
        <translation>檢視</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>喜好設定</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>取消暫停</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>頂端工具列</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>狀態列</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>標題列和工作列按鈕顯示速度</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>捐款</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>全部取消暫停</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>統計資料</translation>
    </message>
    <message>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>全部暫停</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>加入Torrent檔</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>網上說明</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>加入Torrent連結</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>是</translation>
    </message>
    <message>
        <source>No</source>
        <translation>否</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>整體上載速度限制</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>整體下載速度限制</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>確定離開qBittorrent嗎？</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[下載：%1，上載：%2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>特別速度限制</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>搜尋器</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>過濾Torrent清單…</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>傳輸</translation>
    </message>
    <message>
        <source>Move up in the queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move Up Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Bottom of Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move to the bottom of the queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Top of Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move Down Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move down in the queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move to the top of the queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Your browser does not support this feature</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>To use this feature, the WebUI needs to be accessed over HTTPS</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Connection status: Firewalled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Connection status: Connected</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Alternative speed limits: Off</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download speed icon</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Connection status</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Alternative speed limits: On</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload speed icon</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Connection status: Disconnected</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>喜好設定</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>下載</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>連接</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>速度</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Web UI遠端控制</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>語言</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>介面語言：</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>下載完成時以電郵通知</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>完成Torrent時啟動外部程式</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>IP過濾</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>設定使用特別速度限制的時間</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Torrent排程</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>自動加入以下追蹤器到新下載：</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>網絡用戶介面（Web UI遠端控制）</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>IP位址：</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>伺服器域名：</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>使用HTTPS，而不是HTTP</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>略過對本機上用戶的驗證</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>略過對IP子網絡白名單用戶的驗證</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>更新動態域名</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>未完成Torrent存放於：</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>複製「.torrent」檔到：</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>複製完成下載的「.torrent」檔到：</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>預先分配檔案的磁碟空間</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>未完成檔案加上.!qB副檔名</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>自動加入以下位置的Torrent：</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>SMTP伺服器：</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>此伺服器需要加密連接（SSL）</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>驗證</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>用戶名：</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>密碼：</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>已啟用協定：</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP和μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>監聽埠</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>連入埠：</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>使用映射自路由器的UPnP╱NAT-PMP連接埠</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>每次啟動時使用不同的埠</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>連接限制</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>每個Torrent最大連接數量：</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>整體最大連接數量：</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>每個Torrent最大上載通道數量：</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>整體最大上載通道數量：</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>代理伺服器</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>類型：</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>（無）</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>主機：</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>埠：</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>使用代理伺服器來連接同路人</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>代理伺服器僅用於Torrent</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>過濾器（.dat、.p2p、.p2b）</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>手動封鎖IP位址…</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>套用到追蹤器</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>整體速度限制</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>上載：</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>下載：</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>特別速度限制</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>從：</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>到：</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>日期：</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>每日</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>工作日</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>週末</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>設定速度限制</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>將速度限制套用到傳輸消耗</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>將速度限制套用到µTP協定</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>私隱</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>啟用DHT分散式網絡來尋找更多同路人</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>啟用PeX同路人交換來尋找更多同路人</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>啟用LPD本地同路人發現來尋找更多同路人</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>加密模式：</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>要求加密</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>停用加密</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>啟用匿名模式</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>最大活躍下載數量：</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>最大活躍上載數量：</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>最大活躍Torrent數量：</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>此等限制不要計算慢速Torrent</translation>
    </message>
    <message>
        <source>then</source>
        <translation>然後</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>使用UPnP╱NAT-PMP映射路由器連接埠</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>憑證：</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>密匙：</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>註冊</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>域名：</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>支援的參數（大小楷視為不同）：</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>【%N】Torrent名稱</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>【%L】分類</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>【%F】已下載檔案的路徑（單一檔案Torrent）</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>【%R】已下載檔案的路徑（多檔案Torrent首個子資料夾）</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>【%D】儲存路徑</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>【%C】檔案數量</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>【%Z】Torrent大小（位元組）</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>【%T】目前追蹤器</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>【%I】資訊驗證碼</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>提示：以引號包起參數可避免於空格被切斷（例如："%N"）</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>Web UI遠端控制的用戶名最少含3個字元。</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>Web UI遠端控制的密碼最少含6個字元。</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>分鐘</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>啟用防劫持鼠鍵保護</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>啟用防偽造跨站請求（CSRF）保護</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>往後再清除Torrent檔</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>下載速度下限：</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>上載速度下限：</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>更改目前密碼</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>使用後備Web UI遠端控制</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>預設儲存路徑：</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>後備Web UI遠端控制的檔案位置不可空白。</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>不要自動開始下載</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>切換Torrent到手動模式</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>Torrent的分類更改時：</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>遷移受影響Torrent</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>將速度限制套用到區域網絡（LAN）的同路人</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0代表無限</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>遷移Torrent</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>預設儲存路徑更改時：</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>啟用主機標頭驗證</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>驗證</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>分類儲存路徑更改時：</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>為有多個檔案的Torrent建立子資料夾</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>秒</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>切換受影響Torrent到手動模式</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>檔案位置：</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>慢速Torrent時間：</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>預設Torrent管理模式：</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>加入Torrent時</translation>
    </message>
    <message>
        <source>Info: The password is saved unencrypted</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Strict super seeding:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>μTP-TCP mixed mode algorithm:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload rate based</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%G: Tags (separated by comma)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Socket backlog size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable super seeding for torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Prefer TCP</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Outstanding memory when checking torrents:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Anti-leech</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable OS cache:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When ratio reaches</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When seeding time reaches</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Allow multiple connections from the same IP address:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>File pool size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Any interface</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Always announce to all tiers:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Embedded tracker port:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Optional IP Address to bind to (requires restart):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Fastest upload</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Pause torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove torrent and its files</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>qBittorrent Section</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Send buffer watermark factor:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>libtorrent Section</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Coalesce reads &amp; writes:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Outgoing ports (Min) [0: Disabled]:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>IP Address to report to trackers (requires restart):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Recheck torrents on completion:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Allow encryption</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Send upload piece suggestions:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disk cache:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable embedded tracker:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Outgoing ports (Max) [0: Disabled]:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Asynchronous I/O threads:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>s</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Send buffer watermark:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disk cache expiry interval:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Peer proportional (throttles TCP)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Fixed slots</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Advanced</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>min</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload choking algorithm:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeding Limits</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>KiB</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Round-robin</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload slots behavior:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Network Interface (requires restart):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>MiB</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Send buffer low watermark:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Save resume data interval:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Always announce to all trackers in a tier:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Session timeout:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Resolve peer countries:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>ban for:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Use piece extent affinity (requires libtorrent &gt;= 1.2.2):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stop tracker timeout:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Ban client after consecutive failures:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable cookie Secure flag (requires HTTPS)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>UPnP lease duration [0: Permanent lease]:</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>埠</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>旗號</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>連接</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>用戶端</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>進度</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>下載速度</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>上載速度</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>已下載</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>已上載</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>相關度</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>檔案</translation>
    </message>
    <message>
        <source>Ban peer permanently</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Are you sure you want to permanently ban the selected peers?</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy IP:port</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add a new peer...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Country/Region</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>一般</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>高</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>最高</translation>
    </message>
    <message>
        <source>Mixed</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Do not download</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>追蹤器</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>同路人</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>HTTP來源</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>內容</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>已下載：</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>傳輸</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>已用時間：</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>預計剩餘時間：</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>已上載：</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>種子：</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>下載速度：</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>上載速度：</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>同路人：</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>下載速度限制：</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>上載速度限制：</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>已丟棄：</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>連接：</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>資訊</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>評註：</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>分享率：</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>重新公告於：</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>最後完整可見：</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>總大小：</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>片段：</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>編製工具：</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>加入於：</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>完成於：</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>建立於：</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Torrent驗證碼：</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>儲存路徑：</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>從不</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1×%2（完成%3）</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1（本階段%2）</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1（最高%2）</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1（總計%2）</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1（平均%2）</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>下載速度限制：</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>上載速度限制：</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Filter files...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Rename...</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>監視的資料夾</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>覆寫儲存位置</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>監視的資料夾</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>預設儲存位置</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>統計</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>用戶統計</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>快存統計</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>讀取快存次數：</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>排程平均逗留時間：</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>連接的同路人：</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>歷年總分享率：</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>歷年總下載：</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>本階段丟棄：</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>歷年總上載：</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>總緩衝大小：</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>表現統計</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>已排程入出任務：</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>寫入超額快存：</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>讀取超額快存：</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>總排程大小：</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT分散式網絡：%1個節點</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>全部（0）</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>下載中（0）</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>做種（0）</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>完成（0）</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>回復下載（0）</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>暫停（0）</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>活躍（0）</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>不活躍（0）</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>出錯（0）</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>全部（%1）</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>下載中（%1）</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>做種（%1）</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>完成（%1）</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>暫停（%1）</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>回復下載（%1）</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>活躍（%1）</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>不活躍（%1）</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>出錯（%1）</translation>
    </message>
    <message>
        <source>Stalled Uploading (%1)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stalled Downloading (%1)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stalled Downloading (0)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stalled (0)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stalled Uploading (0)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stalled (%1)</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    </context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>名稱</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>大小</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>完成</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>狀態</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>完整種子</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>同路人</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>下載速度</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>上載速度</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>分享率</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>預計剩餘時間</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>分類</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>標籤</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>加入於</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>完成於</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>追蹤器</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>下載速度限制</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>上載速度限制</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>已下載</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>已上載</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>本階段下載</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>本階段上載</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>剩餘</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>已用時間</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>儲存路徑</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>已完成</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>最大分享率</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>最後完整可見</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>最後活動</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>總大小</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>網址</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>狀態</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>同路人</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>訊息</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>已下載</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>追蹤器網址：</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>更新中…</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>運行中</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>已停用</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>未嘗連接</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>（無）</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>種子</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>閒置</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>複製追蹤器網址</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>加入新追蹤器…</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>編輯追蹤器網址…</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>編輯追蹤器</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>依附者</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>清除追蹤器</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Availability</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tier</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download Priority</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Progress</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>加入追蹤器話匣</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>加入的追蹤器清單（一行一個）：</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>%1前</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>分配中</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>暫停</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>已完成</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>遷移中</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>強制做種</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>做種中</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>已排程</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>出錯</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>強制下載</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>正在下載元資料</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>檢查中</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>消失的檔案</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>等待檢查驗證碼</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>下載中</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>檢查項目進度</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>等待開始</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>狀態</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>分類</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Torrent下載速度限制</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Torrent上載速度限制</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重新命名</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>取消暫停</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>強制取消暫停</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>暫停</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>設定最大分享率…</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>限制上載速度…</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>限制下載速度…</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>上移</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>下移</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>移到最上</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>移到最下</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>設定存放位置…</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>先下載首片段和最後片段</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>自動Torrent管理</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>分類</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>新…</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>重設</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>強制重新檢查</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>超級種子模式</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>重新命名…</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>按順序下載</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>強制重新檢查</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>新分類</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>位置</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>新名稱</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>設定存放位置</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>強制重新公告</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>編輯分類</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>儲存路徑</translation>
    </message>
    <message>
        <source>Comma-separated tags:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add Tags</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tags</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Magnet link</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Hash</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove All</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add...</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Torrent分享限制</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>使用整體分享限制</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>不設分享限制</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>設定分享限制到</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>上╱下載比率</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>分鐘</translation>
    </message>
</context>
<context>
    <name>about</name>
    </context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>確認刪除</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>同時從磁碟刪除檔案</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>確認刪除 - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>從網址下載</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>下載</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>加入Torrent連結</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>每秒</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1小時%2分鐘</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1日%2小時</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>未知</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>少於1分鐘</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1分鐘</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>儲存路徑空白</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>附加元件路徑：</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>網址或本機路徑</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>安裝附加元件</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>確定</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>種子：</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>全部附加元件</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>大小：</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>搜尋附加元件…</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>全部類別</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>搜尋：</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>搜尋結果（顯示</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>過濾器</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>僅Torrent名</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>僅已啟用</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>其中</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>全部</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>解除安裝</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>安裝新附加元件</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>需要新的搜尋器附加元件，請到：</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>已安裝的搜尋附加元件：</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>已啟用</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>警告：請確保從此等搜尋器下載Torrent時遵守你所在地的版權規定。</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>檢查更新</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>搜尋附加元件</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>同路人</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>搜尋器</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>完整種子</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>網址</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>已啟用</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>版本</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeersAdditionDialog</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add Peers</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>List of peers to add (one IP per line):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Format: IPv4:port / [IPv6]:port</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TagFilterWidget</name>
    <message>
        <source>New Tag</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add tag...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Delete torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tag:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Pause torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Resume torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove unused tags</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Invalid tag name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove tag</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TagFilterModel</name>
    <message>
        <source>All</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Untagged</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <source>Bug Tracker:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Forum:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>E-mail:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Current maintainer</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Home Page:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Greece</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Special Thanks</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>About qBittorrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>License</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Translators</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>qBittorrent was built with the following libraries:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Nationality:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Author</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Software Used</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>The free IP to Country Lite database by DB-IP is used for resolving the countries of peers. The database is licensed under the Creative Commons Attribution 4.0 International License</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>OptionDialog</name>
    <message>
        <source>All addresses</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All IPv6 addresses</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All IPv4 addresses</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>SearchJobWidget</name>
    <message>
        <source>Copy</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Description page URL</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Open description page</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download link</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TorrentContentTreeView</name>
    <message>
        <source>Renaming</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>New name:</source>
        <translation type="unfinished" />
    </message>
</context>
</TS>